# Copyright @ R. Badeke (2020)

from pandas import DataFrame
from sklearn import linear_model
import statsmodels.api as sm
import matplotlib.pyplot as plt
import pandas as pd
import numpy as np

df = pd.read_csv("C:/User/Desktop/regression_data.csv", sep=";")

print("multilinear regression calculator\n")

"INPUT"
# The user can enter parameters for wind speed, exit velocity, exhaust 
# temperature, wind angle (0 = frontal wind, 90 = lateral wind) and stability 
# to calculate individual downward dispersion values

New_Wind_Speed = 5      # m/s
New_Exit_Velocity = 10     # m/s
New_Temperature = 300   # in degree Celsius
New_angle = 0           # in degree
New_angle = np.cos(np.deg2rad(New_angle))
New_Stability = -0.65   # in K/100 m



Case = df["#"].to_list()
vwind = df["Wind speed"].to_list()
vexh = df["Exit velocity"].to_list()
temperature = df["Temperature"].to_list()
cos_angle = df["cos_Angle"].to_list()
stability = df["dT/dz"].to_list()
stability = [(x * x) if x >= 0 else -(x * x) for x in stability]
D = df["% D"].to_list()


Model_Data = {'Case': Case,
                'Wind Speed': vwind,
                'Exit Velocity': vexh,
                'Temperature': temperature,
                'cos_angle': cos_angle,
                'Stability' : stability,
                'D': D        
                }

df = DataFrame(Model_Data,columns=['Case','Wind Speed','Exit Velocity','Temperature', 'Stability', 'cos_angle', 'D']) 

X = df[['Wind Speed','Exit Velocity','Temperature', 'Stability', 'cos_angle']]
Y = df['D']

# with sklearn
regr = linear_model.LinearRegression()
regr.fit(X, Y)

print("with ship:")
print('Intercept: \n', regr.intercept_)
print('Coefficients for vwind, vexit, Texh, sgn(stability)^2, cos_angle: \n', regr.coef_)


if New_Stability < 0:
    New_Stability = -(New_Stability * New_Stability)
else:
    New_Stability = New_Stability * New_Stability

print ('Predicted D: \n', regr.predict([[New_Wind_Speed ,New_Exit_Velocity, New_Temperature, New_Stability, New_angle]]),'\n')



"*****************************************************************************"

# stack-only


df = pd.read_csv("C:/User/Desktop/regression_data.csv"regression_data.csv", sep=";")

Case = df["#"].to_list()
vwind = df["Wind speed"].to_list()
vexh = df["Exit velocity"].to_list()
temperature = df["Temperature"].to_list()
stability = df["dT/dz"].to_list()
stability = [(x * x) if x >= 0 else -(x * x) for x in stability]
D = df["% D_stack-only"].to_list()


Model_Data = {'Case': Case,
                'Wind Speed': vwind,
                'Exit Velocity': vexh,
                'Temperature': temperature,
                'Stability' : stability,
                'D': D        
                }

df = DataFrame(Model_Data,columns=['Case','Wind Speed','Exit Velocity','Temperature', 'Stability', 'D']) 

X = df[['Wind Speed','Exit Velocity','Temperature', 'Stability']]
Y = df['D']
 
regr = linear_model.LinearRegression()
regr.fit(X, Y)

print("Stack-only: ")

print('Intercept: \n', regr.intercept_)
print('Coefficients for vwind, vexit, Texh, sgn(stability)^2: \n', regr.coef_)
print ('Predicted D: \n', regr.predict([[New_Wind_Speed ,New_Exit_Velocity, New_Temperature, New_Stability]]))
